@@ -8,11 +8,16 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 import constructs._jsii
 import ros_cdk_core._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@alicloud/ros-cdk-redis", "1.0.8", __name__[0:-6], "ros-cdk-redis@1.0.8.jsii.tgz"
+    "@alicloud/ros-cdk-redis",
+    "1.0.12",
+    __name__[0:-6],
+    "ros-cdk-redis@1.0.12.jsii.tgz",
 )
 
 __all__ = [
